@@ -4,9 +4,8 @@ use strict;
 use warnings;
 
 use Carp;
-use DB_File;
 
-use vars qw( $AUTOLOAD );
+use vars qw( $AUTOLOAD %KNOWN_AGENTS );
 
 my $path = '/var/www/awstats/lib';
 if( not -e "$path/robots.pm" or not -e "$path/search_engines.pm" )
@@ -29,26 +28,31 @@ $_ = qr/$_/i for @RobotsSearchIDOrder;
 sub new
 {
 	my ($class,%args) = @_;
-	$args{ TmpRobot } = {};
 	bless \%args, ref($class) || $class;
 }
 
 sub AUTOLOAD
 {
+	return if $AUTOLOAD =~ /[A-Z]$/;
 	$AUTOLOAD =~ s/^.*:://;
-	return if $AUTOLOAD =~ /^[A-Z]/;
 	my( $self, $hit ) = @_;
 	my $UserAgent = $hit->agent
 		or return $self->{handler}->$AUTOLOAD($hit);
+	if( exists $KNOWN_AGENTS{ $UserAgent } )
+	{
+		return $KNOWN_AGENTS{ $UserAgent } ?
+			undef :
+			$self->{handler}->$AUTOLOAD($hit);
+	}
 	for(@RobotsSearchIDOrder)
 	{
 		if( $UserAgent =~ /$_/ )
 		{
-			$self->{ TmpRobot }->{ $UserAgent } = 1;
-			return;
+			$KNOWN_AGENTS{ $UserAgent } = 1;
+			return undef;
 		}
 	}
-	$self->{ TmpRobot }->{ $UserAgent } = 0;
+	$KNOWN_AGENTS{ $UserAgent } = 0;
 	return $self->{handler}->$AUTOLOAD($hit);
 }
 
